==> igniteui-react-charts-18.7.0-beta.2.tgz: package/esm5/lib/PolarAreaSeries_combined.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { PolarLineSeriesBase } from "./PolarLineSeriesBase";
import { UnknownValuePlotting_$type } from "igniteui-react-core";
import { DependencyProperty } from "igniteui-react-core";
import { runOn, enumGetBox, markType, markDep, Point_$type } from "igniteui-react-core";
import { Path } from "igniteui-react-core";
import { List$1 } from "igniteui-react-core";
import { PropertyMetadata } from "igniteui-react-core";
import { PolarLineSeriesBaseView } from "./PolarLineSeriesBaseView";
import { Defaults } from "./Defaults";
import { Color } from "igniteui-react-core";
/**
 * @hidden
 */
var PolarAreaSeries = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(PolarAreaSeries, _super);
    function PolarAreaSeries() {
        var _this = _super.call(this) || this;
        _this.ab = PolarAreaSeries.$;
        return _this;
    }
    PolarAreaSeries.prototype.bi = function () {
        return new PolarAreaSeries();
    };
    PolarAreaSeries.prototype.get_es = function () {
        return true;
    };
    PolarAreaSeries.prototype.cq = function () {
        return new PolarAreaSeriesView(this);
    };
    PolarAreaSeries.prototype.zp = function () {
        return false;
    };
    PolarAreaSeries.prototype.qw = function (a) {
        _super.prototype.qw.call(this, a);
        this.acl = a;
    };
    PolarAreaSeries.prototype.acj = function (a) {
        var b = a;
        b.da();
    };
    PolarAreaSeries.prototype.ack = function (a, b) {
        if (a.m.count > 0) {
            var c = a.m._inner[0];
            var d = a.m._inner[a.m.count - 1];
            var e = c.x == d.x && c.y == d.y;
            if (!e) {
                a.m.add(a.m._inner[0]);
            }
        }
        var f = b;
        f.db(a.m, this.ib);
        this.yw.az(this, this.zo(), runOn(this, this.ye));
        var g = false;
        var h = this.yw.b;
        if (h != null) {
            g = true;
        }
        if (g) {
            this.aa3(-1, this.za.count, b.q);
        }
        var i = f.dh;
        var j = f.dg;
        this.yw.ad(i, true, false, true, true);
        this.yw.ad(j, false, true, false, false);
        j._opacity = this.yw.j * this.h7;
    };
    PolarAreaSeries.prototype.get_acg = function () {
        return true;
    };
    PolarAreaSeries.prototype.acb = function () {
        return this.acm;
    };
    PolarAreaSeries.$t = markType(PolarAreaSeries, 'PolarAreaSeries', PolarLineSeriesBase.$);
    PolarAreaSeries.$$p = markDep(DependencyProperty, PropertyMetadata, PolarAreaSeries, 'raisePropertyChanged', ['UnknownValuePlotting:acm:aco', [UnknownValuePlotting_$type, enumGetBox(UnknownValuePlotting_$type, 1)]]);
    return PolarAreaSeries;
}(PolarLineSeriesBase));
export { PolarAreaSeries };
/**
 * @hidden
 */
var PolarAreaSeriesView = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(PolarAreaSeriesView, _super);
    function PolarAreaSeriesView(a) {
        var _this = _super.call(this, a) || this;
        _this.c9 = null;
        _this.df = new Path();
        _this.de = new Path();
        _this.dd = new Path();
        _this.dc = new Path();
        _this.c9 = a;
        return _this;
    }
    PolarAreaSeriesView.prototype.au = function () {
        _super.prototype.au.call(this);
        if (!this.q) {
            this.c9.w1 = Defaults.e;
        }
    };
    Object.defineProperty(PolarAreaSeriesView.prototype, "dg", {
        get: function () {
            return this.de;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(PolarAreaSeriesView.prototype, "dh", {
        get: function () {
            return this.df;
        },
        enumerable: false,
        configurable: true
    });
    PolarAreaSeriesView.prototype.da = function () {
        this.de.an = null;
        this.df.an = null;
        this.dc.an = null;
        this.dd.an = null;
        this.as();
    };
    PolarAreaSeriesView.prototype.db = function (a, b) {
        var c = new List$1(Point_$type, 1, a);
        this.c9.ab8.d(this.df, c, b);
        this.c9.ab8.d(this.de, c, b);
        this.as();
    };
    PolarAreaSeriesView.prototype.bd = function () {
        _super.prototype.bd.call(this);
    };
    PolarAreaSeriesView.prototype.be = function () {
        _super.prototype.be.call(this);
        var a = this.br();
        this.dd.an = this.df.an;
        this.dc.an = this.de.an;
        this.dd._stroke = a;
        this.dd.ad = this.e.ic + 3;
        this.dc._fill = a;
        this.dc._opacity = 1;
    };
    PolarAreaSeriesView.prototype.a8 = function (a, b) {
        _super.prototype.a8.call(this, a, b);
        if (a.d) {
            if (b) {
                a.t(this.dc);
                a.t(this.dd);
            }
            else {
                a.t(this.de);
                a.t(this.df);
            }
        }
    };
    PolarAreaSeriesView.prototype.an = function (a) {
        _super.prototype.an.call(this, a);
        this.e.bb.exportPathData(a, this.df, "polarShape", ["Main"]);
        this.e.bb.exportPathData(a, this.de, "fillShape", ["Fill"]);
    };
    PolarAreaSeriesView.prototype.af = function () {
        var a = new Color();
        a.colorString = "rgba(95,95,95,0.5)";
        this.e.vu = a;
        this.e.jk = 5;
        this.e.jl = 5;
        this.e.jm = 5;
    };
    PolarAreaSeriesView.$t = markType(PolarAreaSeriesView, 'PolarAreaSeriesView', PolarLineSeriesBaseView.$);
    return PolarAreaSeriesView;
}(PolarLineSeriesBaseView));
export { PolarAreaSeriesView };

==> igniteui-react-charts-18.7.5-beta.2.tgz: package/esm5/lib/PolarAreaSeries_combined.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { PolarLineSeriesBase } from "./PolarLineSeriesBase";
import { UnknownValuePlotting_$type } from "igniteui-react-core";
import { DependencyProperty } from "igniteui-react-core";
import { runOn, enumGetBox, markType, markDep, Point_$type } from "igniteui-react-core";
import { Path } from "igniteui-react-core";
import { List$1 } from "igniteui-react-core";
import { PropertyMetadata } from "igniteui-react-core";
import { PolarLineSeriesBaseView } from "./PolarLineSeriesBaseView";
import { Defaults } from "./Defaults";
import { Color } from "igniteui-react-core";
/**
 * @hidden
 */
var PolarAreaSeries = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(PolarAreaSeries, _super);
    function PolarAreaSeries() {
        var _this = _super.call(this) || this;
        _this.ab = PolarAreaSeries.$;
        return _this;
    }
    PolarAreaSeries.prototype.bj = function () {
        return new PolarAreaSeries();
    };
    PolarAreaSeries.prototype.get_eu = function () {
        return true;
    };
    PolarAreaSeries.prototype.cs = function () {
        return new PolarAreaSeriesView(this);
    };
    PolarAreaSeries.prototype.zy = function () {
        return false;
    };
    PolarAreaSeries.prototype.q1 = function (a) {
        _super.prototype.q1.call(this, a);
        this.acu = a;
    };
    PolarAreaSeries.prototype.acs = function (a) {
        var b = a;
        b.da();
    };
    PolarAreaSeries.prototype.act = function (a, b) {
        if (a.m.count > 0) {
            var c = a.m._inner[0];
            var d = a.m._inner[a.m.count - 1];
            var e = c.x == d.x && c.y == d.y;
            if (!e) {
                a.m.add(a.m._inner[0]);
            }
        }
        var f = b;
        f.db(a.m, this.id);
        this.y5.az(this, this.zx(), runOn(this, this.yn));
        var g = false;
        var h = this.y5.b;
        if (h != null) {
            g = true;
        }
        if (g) {
            this.abc(-1, this.zj.count, b.q);
        }
        var i = f.dh;
        var j = f.dg;
        this.y5.ad(i, true, false, true, true);
        this.y5.ad(j, false, true, false, false);
        j._opacity = this.y5.j * this.h9;
    };
    PolarAreaSeries.prototype.get_acp = function () {
        return true;
    };
    PolarAreaSeries.prototype.ack = function () {
        return this.acv;
    };
    PolarAreaSeries.$t = markType(PolarAreaSeries, 'PolarAreaSeries', PolarLineSeriesBase.$);
    PolarAreaSeries.$$p = markDep(DependencyProperty, PropertyMetadata, PolarAreaSeries, 'raisePropertyChanged', ['UnknownValuePlotting:acv:acx', [UnknownValuePlotting_$type, enumGetBox(UnknownValuePlotting_$type, 1)]]);
    return PolarAreaSeries;
}(PolarLineSeriesBase));
export { PolarAreaSeries };
/**
 * @hidden
 */
var PolarAreaSeriesView = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(PolarAreaSeriesView, _super);
    function PolarAreaSeriesView(a) {
        var _this = _super.call(this, a) || this;
        _this.c9 = null;
        _this.df = new Path();
        _this.de = new Path();
        _this.dd = new Path();
        _this.dc = new Path();
        _this.c9 = a;
        return _this;
    }
    PolarAreaSeriesView.prototype.au = function () {
        _super.prototype.au.call(this);
        if (!this.q) {
            this.c9.xa = Defaults.e;
        }
    };
    Object.defineProperty(PolarAreaSeriesView.prototype, "dg", {
        get: function () {
            return this.de;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(PolarAreaSeriesView.prototype, "dh", {
        get: function () {
            return this.df;
        },
        enumerable: false,
        configurable: true
    });
    PolarAreaSeriesView.prototype.da = function () {
        this.de.an = null;
        this.df.an = null;
        this.dc.an = null;
        this.dd.an = null;
        this.as();
    };
    PolarAreaSeriesView.prototype.db = function (a, b) {
        var c = new List$1(Point_$type, 1, a);
        this.c9.ach.d(this.df, c, b);
        this.c9.ach.d(this.de, c, b);
        this.as();
    };
    PolarAreaSeriesView.prototype.bd = function () {
        _super.prototype.bd.call(this);
    };
    PolarAreaSeriesView.prototype.be = function () {
        _super.prototype.be.call(this);
        var a = this.br();
        this.dd.an = this.df.an;
        this.dc.an = this.de.an;
        this.dd._stroke = a;
        this.dd.ad = this.e.ie + 3;
        this.dc._fill = a;
        this.dc._opacity = 1;
    };
    PolarAreaSeriesView.prototype.a8 = function (a, b) {
        _super.prototype.a8.call(this, a, b);
        if (a.d) {
            if (b) {
                a.t(this.dc);
                a.t(this.dd);
            }
            else {
                a.t(this.de);
                a.t(this.df);
            }
        }
    };
    PolarAreaSeriesView.prototype.an = function (a) {
        _super.prototype.an.call(this, a);
        this.e.bc.exportPathData(a, this.df, "polarShape", ["Main"]);
        this.e.bc.exportPathData(a, this.de, "fillShape", ["Fill"]);
    };
    PolarAreaSeriesView.prototype.af = function () {
        var a = new Color();
        a.colorString = "rgba(95,95,95,0.5)";
        this.e.v1 = a;
        this.e.jm = 5;
        this.e.jn = 5;
        this.e.jo = 5;
    };
    PolarAreaSeriesView.$t = markType(PolarAreaSeriesView, 'PolarAreaSeriesView', PolarLineSeriesBaseView.$);
    return PolarAreaSeriesView;
}(PolarLineSeriesBaseView));
export { PolarAreaSeriesView };
